# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/third_party_perception/proto/radar_obstacle.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import error_code_pb2 as modules_dot_common_dot_proto_dot_error__code__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/third_party_perception/proto/radar_obstacle.proto',
  package='apollo.third_party_perception',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n9modules/third_party_perception/proto/radar_obstacle.proto\x12\x1d\x61pollo.third_party_perception\x1a%modules/common/proto/error_code.proto\x1a!modules/common/proto/header.proto\x1a#modules/common/proto/geometry.proto\"\xef\x02\n\rRadarObstacle\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x31\n\x11relative_position\x18\x02 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x31\n\x11relative_velocity\x18\x03 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x0b\n\x03rcs\x18\x04 \x01(\x01\x12\x0f\n\x07movable\x18\x05 \x01(\x08\x12\r\n\x05width\x18\x06 \x01(\x01\x12\x0e\n\x06length\x18\x07 \x01(\x01\x12\x0e\n\x06height\x18\x08 \x01(\x01\x12\r\n\x05theta\x18\t \x01(\x01\x12\x31\n\x11\x61\x62solute_position\x18\n \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x31\n\x11\x61\x62solute_velocity\x18\x0b \x01(\x0b\x32\x16.apollo.common.Point3D\x12\r\n\x05\x63ount\x18\x0c \x01(\x05\x12\x1b\n\x13moving_frames_count\x18\r \x01(\x05\"\xa7\x02\n\x0eRadarObstacles\x12X\n\x0eradar_obstacle\x18\x01 \x03(\x0b\x32@.apollo.third_party_perception.RadarObstacles.RadarObstacleEntry\x12%\n\x06header\x18\x02 \x01(\x0b\x32\x15.apollo.common.Header\x12\x30\n\nerror_code\x18\x03 \x01(\x0e\x32\x18.apollo.common.ErrorCode:\x02OK\x1a\x62\n\x12RadarObstacleEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12;\n\x05value\x18\x02 \x01(\x0b\x32,.apollo.third_party_perception.RadarObstacle:\x02\x38\x01'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_error__code__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])




_RADAROBSTACLE = _descriptor.Descriptor(
  name='RadarObstacle',
  full_name='apollo.third_party_perception.RadarObstacle',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.third_party_perception.RadarObstacle.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_position', full_name='apollo.third_party_perception.RadarObstacle.relative_position', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='relative_velocity', full_name='apollo.third_party_perception.RadarObstacle.relative_velocity', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rcs', full_name='apollo.third_party_perception.RadarObstacle.rcs', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='movable', full_name='apollo.third_party_perception.RadarObstacle.movable', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='width', full_name='apollo.third_party_perception.RadarObstacle.width', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='length', full_name='apollo.third_party_perception.RadarObstacle.length', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='apollo.third_party_perception.RadarObstacle.height', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='theta', full_name='apollo.third_party_perception.RadarObstacle.theta', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='absolute_position', full_name='apollo.third_party_perception.RadarObstacle.absolute_position', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='absolute_velocity', full_name='apollo.third_party_perception.RadarObstacle.absolute_velocity', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='count', full_name='apollo.third_party_perception.RadarObstacle.count', index=11,
      number=12, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='moving_frames_count', full_name='apollo.third_party_perception.RadarObstacle.moving_frames_count', index=12,
      number=13, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=571,
)


_RADAROBSTACLES_RADAROBSTACLEENTRY = _descriptor.Descriptor(
  name='RadarObstacleEntry',
  full_name='apollo.third_party_perception.RadarObstacles.RadarObstacleEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.third_party_perception.RadarObstacles.RadarObstacleEntry.key', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.third_party_perception.RadarObstacles.RadarObstacleEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=771,
  serialized_end=869,
)

_RADAROBSTACLES = _descriptor.Descriptor(
  name='RadarObstacles',
  full_name='apollo.third_party_perception.RadarObstacles',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='radar_obstacle', full_name='apollo.third_party_perception.RadarObstacles.radar_obstacle', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.third_party_perception.RadarObstacles.header', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_code', full_name='apollo.third_party_perception.RadarObstacles.error_code', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_RADAROBSTACLES_RADAROBSTACLEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=574,
  serialized_end=869,
)

_RADAROBSTACLE.fields_by_name['relative_position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_RADAROBSTACLE.fields_by_name['relative_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_RADAROBSTACLE.fields_by_name['absolute_position'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_RADAROBSTACLE.fields_by_name['absolute_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_RADAROBSTACLES_RADAROBSTACLEENTRY.fields_by_name['value'].message_type = _RADAROBSTACLE
_RADAROBSTACLES_RADAROBSTACLEENTRY.containing_type = _RADAROBSTACLES
_RADAROBSTACLES.fields_by_name['radar_obstacle'].message_type = _RADAROBSTACLES_RADAROBSTACLEENTRY
_RADAROBSTACLES.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_RADAROBSTACLES.fields_by_name['error_code'].enum_type = modules_dot_common_dot_proto_dot_error__code__pb2._ERRORCODE
DESCRIPTOR.message_types_by_name['RadarObstacle'] = _RADAROBSTACLE
DESCRIPTOR.message_types_by_name['RadarObstacles'] = _RADAROBSTACLES
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

RadarObstacle = _reflection.GeneratedProtocolMessageType('RadarObstacle', (_message.Message,), {
  'DESCRIPTOR' : _RADAROBSTACLE,
  '__module__' : 'modules.third_party_perception.proto.radar_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.third_party_perception.RadarObstacle)
  })
_sym_db.RegisterMessage(RadarObstacle)

RadarObstacles = _reflection.GeneratedProtocolMessageType('RadarObstacles', (_message.Message,), {

  'RadarObstacleEntry' : _reflection.GeneratedProtocolMessageType('RadarObstacleEntry', (_message.Message,), {
    'DESCRIPTOR' : _RADAROBSTACLES_RADAROBSTACLEENTRY,
    '__module__' : 'modules.third_party_perception.proto.radar_obstacle_pb2'
    # @@protoc_insertion_point(class_scope:apollo.third_party_perception.RadarObstacles.RadarObstacleEntry)
    })
  ,
  'DESCRIPTOR' : _RADAROBSTACLES,
  '__module__' : 'modules.third_party_perception.proto.radar_obstacle_pb2'
  # @@protoc_insertion_point(class_scope:apollo.third_party_perception.RadarObstacles)
  })
_sym_db.RegisterMessage(RadarObstacles)
_sym_db.RegisterMessage(RadarObstacles.RadarObstacleEntry)


_RADAROBSTACLES_RADAROBSTACLEENTRY._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/storytelling/proto/storytelling_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/storytelling/proto/storytelling_config.proto',
  package='apollo.storytelling',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n4modules/storytelling/proto/storytelling_config.proto\x12\x13\x61pollo.storytelling\"L\n\x0bTopicConfig\x12!\n\x19planning_trajectory_topic\x18\x01 \x01(\t\x12\x1a\n\x12storytelling_topic\x18\x02 \x01(\t\"L\n\x12StorytellingConfig\x12\x36\n\x0ctopic_config\x18\x01 \x01(\x0b\x32 .apollo.storytelling.TopicConfig'
)




_TOPICCONFIG = _descriptor.Descriptor(
  name='TopicConfig',
  full_name='apollo.storytelling.TopicConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='planning_trajectory_topic', full_name='apollo.storytelling.TopicConfig.planning_trajectory_topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storytelling_topic', full_name='apollo.storytelling.TopicConfig.storytelling_topic', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=153,
)


_STORYTELLINGCONFIG = _descriptor.Descriptor(
  name='StorytellingConfig',
  full_name='apollo.storytelling.StorytellingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic_config', full_name='apollo.storytelling.StorytellingConfig.topic_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=155,
  serialized_end=231,
)

_STORYTELLINGCONFIG.fields_by_name['topic_config'].message_type = _TOPICCONFIG
DESCRIPTOR.message_types_by_name['TopicConfig'] = _TOPICCONFIG
DESCRIPTOR.message_types_by_name['StorytellingConfig'] = _STORYTELLINGCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TopicConfig = _reflection.GeneratedProtocolMessageType('TopicConfig', (_message.Message,), {
  'DESCRIPTOR' : _TOPICCONFIG,
  '__module__' : 'modules.storytelling.proto.storytelling_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.storytelling.TopicConfig)
  })
_sym_db.RegisterMessage(TopicConfig)

StorytellingConfig = _reflection.GeneratedProtocolMessageType('StorytellingConfig', (_message.Message,), {
  'DESCRIPTOR' : _STORYTELLINGCONFIG,
  '__module__' : 'modules.storytelling.proto.storytelling_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.storytelling.StorytellingConfig)
  })
_sym_db.RegisterMessage(StorytellingConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/common/vehicle_state/proto/vehicle_state.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.localization.proto import pose_pb2 as modules_dot_localization_dot_proto_dot_pose__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/common/vehicle_state/proto/vehicle_state.proto',
  package='apollo.common',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n6modules/common/vehicle_state/proto/vehicle_state.proto\x12\rapollo.common\x1a\"modules/canbus/proto/chassis.proto\x1a%modules/localization/proto/pose.proto\"\xb3\x03\n\x0cVehicleState\x12\x0c\n\x01x\x18\x01 \x01(\x01:\x01\x30\x12\x0c\n\x01y\x18\x02 \x01(\x01:\x01\x30\x12\x0c\n\x01z\x18\x03 \x01(\x01:\x01\x30\x12\x14\n\ttimestamp\x18\x04 \x01(\x01:\x01\x30\x12\x0f\n\x04roll\x18\x05 \x01(\x01:\x01\x30\x12\x10\n\x05pitch\x18\x06 \x01(\x01:\x01\x30\x12\x0e\n\x03yaw\x18\x07 \x01(\x01:\x01\x30\x12\x12\n\x07heading\x18\x08 \x01(\x01:\x01\x30\x12\x10\n\x05kappa\x18\t \x01(\x01:\x01\x30\x12\x1a\n\x0flinear_velocity\x18\n \x01(\x01:\x01\x30\x12\x1b\n\x10\x61ngular_velocity\x18\x0b \x01(\x01:\x01\x30\x12\x1e\n\x13linear_acceleration\x18\x0c \x01(\x01:\x01\x30\x12\x31\n\x04gear\x18\r \x01(\x0e\x32#.apollo.canbus.Chassis.GearPosition\x12\x38\n\x0c\x64riving_mode\x18\x0e \x01(\x0e\x32\".apollo.canbus.Chassis.DrivingMode\x12\'\n\x04pose\x18\x0f \x01(\x0b\x32\x19.apollo.localization.Pose\x12\x1b\n\x13steering_percentage\x18\x10 \x01(\x01'
  ,
  dependencies=[modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_localization_dot_proto_dot_pose__pb2.DESCRIPTOR,])




_VEHICLESTATE = _descriptor.Descriptor(
  name='VehicleState',
  full_name='apollo.common.VehicleState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='x', full_name='apollo.common.VehicleState.x', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='y', full_name='apollo.common.VehicleState.y', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='z', full_name='apollo.common.VehicleState.z', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.common.VehicleState.timestamp', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='roll', full_name='apollo.common.VehicleState.roll', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pitch', full_name='apollo.common.VehicleState.pitch', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yaw', full_name='apollo.common.VehicleState.yaw', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.common.VehicleState.heading', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kappa', full_name='apollo.common.VehicleState.kappa', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_velocity', full_name='apollo.common.VehicleState.linear_velocity', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity', full_name='apollo.common.VehicleState.angular_velocity', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_acceleration', full_name='apollo.common.VehicleState.linear_acceleration', index=11,
      number=12, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear', full_name='apollo.common.VehicleState.gear', index=12,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driving_mode', full_name='apollo.common.VehicleState.driving_mode', index=13,
      number=14, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pose', full_name='apollo.common.VehicleState.pose', index=14,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='steering_percentage', full_name='apollo.common.VehicleState.steering_percentage', index=15,
      number=16, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=149,
  serialized_end=584,
)

_VEHICLESTATE.fields_by_name['gear'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_GEARPOSITION
_VEHICLESTATE.fields_by_name['driving_mode'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_DRIVINGMODE
_VEHICLESTATE.fields_by_name['pose'].message_type = modules_dot_localization_dot_proto_dot_pose__pb2._POSE
DESCRIPTOR.message_types_by_name['VehicleState'] = _VEHICLESTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VehicleState = _reflection.GeneratedProtocolMessageType('VehicleState', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLESTATE,
  '__module__' : 'modules.common.vehicle_state.proto.vehicle_state_pb2'
  # @@protoc_insertion_point(class_scope:apollo.common.VehicleState)
  })
_sym_db.RegisterMessage(VehicleState)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/planning.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.common.proto import drive_state_pb2 as modules_dot_common_dot_proto_dot_drive__state__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2
from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import pnc_point_pb2 as modules_dot_common_dot_proto_dot_pnc__point__pb2
from modules.map.proto import map_id_pb2 as modules_dot_map_dot_proto_dot_map__id__pb2
from modules.planning.proto import decision_pb2 as modules_dot_planning_dot_proto_dot_decision__pb2
from modules.planning.proto import planning_internal_pb2 as modules_dot_planning_dot_proto_dot_planning__internal__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/planning.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/planning/proto/planning.proto\x12\x0f\x61pollo.planning\x1a\"modules/canbus/proto/chassis.proto\x1a&modules/common/proto/drive_state.proto\x1a#modules/common/proto/geometry.proto\x1a!modules/common/proto/header.proto\x1a$modules/common/proto/pnc_point.proto\x1a\x1emodules/map/proto/map_id.proto\x1a%modules/planning/proto/decision.proto\x1a.modules/planning/proto/planning_internal.proto\")\n\x05\x45Stop\x12\x10\n\x08is_estop\x18\x01 \x01(\x08\x12\x0e\n\x06reason\x18\x02 \x01(\t\"*\n\tTaskStats\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07time_ms\x18\x02 \x01(\x01\"q\n\x0cLatencyStats\x12\x15\n\rtotal_time_ms\x18\x01 \x01(\x01\x12.\n\ntask_stats\x18\x02 \x03(\x0b\x32\x1a.apollo.planning.TaskStats\x12\x1a\n\x12init_frame_time_ms\x18\x03 \x01(\x01\"\x9f\x02\n\x07RSSInfo\x12\x13\n\x0bis_rss_safe\x18\x01 \x01(\x08\x12\x14\n\x0c\x63ur_dist_lon\x18\x02 \x01(\x01\x12\x19\n\x11rss_safe_dist_lon\x18\x03 \x01(\x01\x12\x1d\n\x15\x61\x63\x63_lon_range_minimum\x18\x04 \x01(\x01\x12\x1d\n\x15\x61\x63\x63_lon_range_maximum\x18\x05 \x01(\x01\x12\"\n\x1a\x61\x63\x63_lat_left_range_minimum\x18\x06 \x01(\x01\x12\"\n\x1a\x61\x63\x63_lat_left_range_maximum\x18\x07 \x01(\x01\x12#\n\x1b\x61\x63\x63_lat_right_range_minimum\x18\x08 \x01(\x01\x12#\n\x1b\x61\x63\x63_lat_right_range_maximum\x18\t \x01(\x01\"\x8a\t\n\rADCTrajectory\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x19\n\x11total_path_length\x18\x02 \x01(\x01\x12\x17\n\x0ftotal_path_time\x18\x03 \x01(\x01\x12\x38\n\x10trajectory_point\x18\x0c \x03(\x0b\x32\x1e.apollo.common.TrajectoryPoint\x12%\n\x05\x65stop\x18\x06 \x01(\x0b\x32\x16.apollo.planning.EStop\x12,\n\npath_point\x18\r \x03(\x0b\x32\x18.apollo.common.PathPoint\x12\x18\n\tis_replan\x18\t \x01(\x08:\x05\x66\x61lse\x12\x15\n\rreplan_reason\x18\x16 \x01(\t\x12\x31\n\x04gear\x18\n \x01(\x0e\x32#.apollo.canbus.Chassis.GearPosition\x12\x31\n\x08\x64\x65\x63ision\x18\x0e \x01(\x0b\x32\x1f.apollo.planning.DecisionResult\x12\x34\n\rlatency_stats\x18\x0f \x01(\x0b\x32\x1d.apollo.planning.LatencyStats\x12-\n\x0erouting_header\x18\x10 \x01(\x0b\x32\x15.apollo.common.Header\x12.\n\x05\x64\x65\x62ug\x18\x08 \x01(\x0b\x32\x1f.apollo.planning_internal.Debug\x12L\n\x13right_of_way_status\x18\x11 \x01(\x0e\x32/.apollo.planning.ADCTrajectory.RightOfWayStatus\x12!\n\x07lane_id\x18\x12 \x03(\x0b\x32\x10.apollo.hdmap.Id\x12\x32\n\rengage_advice\x18\x13 \x01(\x0b\x32\x1b.apollo.common.EngageAdvice\x12\x46\n\x0f\x63ritical_region\x18\x14 \x01(\x0b\x32-.apollo.planning.ADCTrajectory.CriticalRegion\x12O\n\x0ftrajectory_type\x18\x15 \x01(\x0e\x32-.apollo.planning.ADCTrajectory.TrajectoryType:\x07UNKNOWN\x12(\n\x0etarget_lane_id\x18\x17 \x03(\x0b\x32\x10.apollo.hdmap.Id\x12*\n\x08rss_info\x18\x64 \x01(\x0b\x32\x18.apollo.planning.RSSInfo\x1a\x38\n\x0e\x43riticalRegion\x12&\n\x06region\x18\x01 \x03(\x0b\x32\x16.apollo.common.Polygon\"2\n\x10RightOfWayStatus\x12\x0f\n\x0bUNPROTECTED\x10\x00\x12\r\n\tPROTECTED\x10\x01\"a\n\x0eTrajectoryType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\x11\n\rPATH_FALLBACK\x10\x02\x12\x12\n\x0eSPEED_FALLBACK\x10\x03\x12\x0f\n\x0bPATH_REUSED\x10\x04'
  ,
  dependencies=[modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_drive__state__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_pnc__point__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__id__pb2.DESCRIPTOR,modules_dot_planning_dot_proto_dot_decision__pb2.DESCRIPTOR,modules_dot_planning_dot_proto_dot_planning__internal__pb2.DESCRIPTOR,])



_ADCTRAJECTORY_RIGHTOFWAYSTATUS = _descriptor.EnumDescriptor(
  name='RightOfWayStatus',
  full_name='apollo.planning.ADCTrajectory.RightOfWayStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNPROTECTED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTECTED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1869,
  serialized_end=1919,
)
_sym_db.RegisterEnumDescriptor(_ADCTRAJECTORY_RIGHTOFWAYSTATUS)

_ADCTRAJECTORY_TRAJECTORYTYPE = _descriptor.EnumDescriptor(
  name='TrajectoryType',
  full_name='apollo.planning.ADCTrajectory.TrajectoryType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PATH_FALLBACK', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SPEED_FALLBACK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PATH_REUSED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1921,
  serialized_end=2018,
)
_sym_db.RegisterEnumDescriptor(_ADCTRAJECTORY_TRAJECTORYTYPE)


_ESTOP = _descriptor.Descriptor(
  name='EStop',
  full_name='apollo.planning.EStop',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_estop', full_name='apollo.planning.EStop.is_estop', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reason', full_name='apollo.planning.EStop.reason', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=363,
  serialized_end=404,
)


_TASKSTATS = _descriptor.Descriptor(
  name='TaskStats',
  full_name='apollo.planning.TaskStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.planning.TaskStats.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_ms', full_name='apollo.planning.TaskStats.time_ms', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=406,
  serialized_end=448,
)


_LATENCYSTATS = _descriptor.Descriptor(
  name='LatencyStats',
  full_name='apollo.planning.LatencyStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_time_ms', full_name='apollo.planning.LatencyStats.total_time_ms', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='task_stats', full_name='apollo.planning.LatencyStats.task_stats', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='init_frame_time_ms', full_name='apollo.planning.LatencyStats.init_frame_time_ms', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=450,
  serialized_end=563,
)


_RSSINFO = _descriptor.Descriptor(
  name='RSSInfo',
  full_name='apollo.planning.RSSInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_rss_safe', full_name='apollo.planning.RSSInfo.is_rss_safe', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cur_dist_lon', full_name='apollo.planning.RSSInfo.cur_dist_lon', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rss_safe_dist_lon', full_name='apollo.planning.RSSInfo.rss_safe_dist_lon', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_lon_range_minimum', full_name='apollo.planning.RSSInfo.acc_lon_range_minimum', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_lon_range_maximum', full_name='apollo.planning.RSSInfo.acc_lon_range_maximum', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_lat_left_range_minimum', full_name='apollo.planning.RSSInfo.acc_lat_left_range_minimum', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_lat_left_range_maximum', full_name='apollo.planning.RSSInfo.acc_lat_left_range_maximum', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_lat_right_range_minimum', full_name='apollo.planning.RSSInfo.acc_lat_right_range_minimum', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acc_lat_right_range_maximum', full_name='apollo.planning.RSSInfo.acc_lat_right_range_maximum', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=853,
)


_ADCTRAJECTORY_CRITICALREGION = _descriptor.Descriptor(
  name='CriticalRegion',
  full_name='apollo.planning.ADCTrajectory.CriticalRegion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='region', full_name='apollo.planning.ADCTrajectory.CriticalRegion.region', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1811,
  serialized_end=1867,
)

_ADCTRAJECTORY = _descriptor.Descriptor(
  name='ADCTrajectory',
  full_name='apollo.planning.ADCTrajectory',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.planning.ADCTrajectory.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_path_length', full_name='apollo.planning.ADCTrajectory.total_path_length', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='total_path_time', full_name='apollo.planning.ADCTrajectory.total_path_time', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_point', full_name='apollo.planning.ADCTrajectory.trajectory_point', index=3,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='estop', full_name='apollo.planning.ADCTrajectory.estop', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path_point', full_name='apollo.planning.ADCTrajectory.path_point', index=5,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_replan', full_name='apollo.planning.ADCTrajectory.is_replan', index=6,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replan_reason', full_name='apollo.planning.ADCTrajectory.replan_reason', index=7,
      number=22, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gear', full_name='apollo.planning.ADCTrajectory.gear', index=8,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='decision', full_name='apollo.planning.ADCTrajectory.decision', index=9,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latency_stats', full_name='apollo.planning.ADCTrajectory.latency_stats', index=10,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_header', full_name='apollo.planning.ADCTrajectory.routing_header', index=11,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='debug', full_name='apollo.planning.ADCTrajectory.debug', index=12,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_of_way_status', full_name='apollo.planning.ADCTrajectory.right_of_way_status', index=13,
      number=17, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.planning.ADCTrajectory.lane_id', index=14,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='engage_advice', full_name='apollo.planning.ADCTrajectory.engage_advice', index=15,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='critical_region', full_name='apollo.planning.ADCTrajectory.critical_region', index=16,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='trajectory_type', full_name='apollo.planning.ADCTrajectory.trajectory_type', index=17,
      number=21, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_lane_id', full_name='apollo.planning.ADCTrajectory.target_lane_id', index=18,
      number=23, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rss_info', full_name='apollo.planning.ADCTrajectory.rss_info', index=19,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ADCTRAJECTORY_CRITICALREGION, ],
  enum_types=[
    _ADCTRAJECTORY_RIGHTOFWAYSTATUS,
    _ADCTRAJECTORY_TRAJECTORYTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=856,
  serialized_end=2018,
)

_LATENCYSTATS.fields_by_name['task_stats'].message_type = _TASKSTATS
_ADCTRAJECTORY_CRITICALREGION.fields_by_name['region'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POLYGON
_ADCTRAJECTORY_CRITICALREGION.containing_type = _ADCTRAJECTORY
_ADCTRAJECTORY.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_ADCTRAJECTORY.fields_by_name['trajectory_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._TRAJECTORYPOINT
_ADCTRAJECTORY.fields_by_name['estop'].message_type = _ESTOP
_ADCTRAJECTORY.fields_by_name['path_point'].message_type = modules_dot_common_dot_proto_dot_pnc__point__pb2._PATHPOINT
_ADCTRAJECTORY.fields_by_name['gear'].enum_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._CHASSIS_GEARPOSITION
_ADCTRAJECTORY.fields_by_name['decision'].message_type = modules_dot_planning_dot_proto_dot_decision__pb2._DECISIONRESULT
_ADCTRAJECTORY.fields_by_name['latency_stats'].message_type = _LATENCYSTATS
_ADCTRAJECTORY.fields_by_name['routing_header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_ADCTRAJECTORY.fields_by_name['debug'].message_type = modules_dot_planning_dot_proto_dot_planning__internal__pb2._DEBUG
_ADCTRAJECTORY.fields_by_name['right_of_way_status'].enum_type = _ADCTRAJECTORY_RIGHTOFWAYSTATUS
_ADCTRAJECTORY.fields_by_name['lane_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_ADCTRAJECTORY.fields_by_name['engage_advice'].message_type = modules_dot_common_dot_proto_dot_drive__state__pb2._ENGAGEADVICE
_ADCTRAJECTORY.fields_by_name['critical_region'].message_type = _ADCTRAJECTORY_CRITICALREGION
_ADCTRAJECTORY.fields_by_name['trajectory_type'].enum_type = _ADCTRAJECTORY_TRAJECTORYTYPE
_ADCTRAJECTORY.fields_by_name['target_lane_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_ADCTRAJECTORY.fields_by_name['rss_info'].message_type = _RSSINFO
_ADCTRAJECTORY_RIGHTOFWAYSTATUS.containing_type = _ADCTRAJECTORY
_ADCTRAJECTORY_TRAJECTORYTYPE.containing_type = _ADCTRAJECTORY
DESCRIPTOR.message_types_by_name['EStop'] = _ESTOP
DESCRIPTOR.message_types_by_name['TaskStats'] = _TASKSTATS
DESCRIPTOR.message_types_by_name['LatencyStats'] = _LATENCYSTATS
DESCRIPTOR.message_types_by_name['RSSInfo'] = _RSSINFO
DESCRIPTOR.message_types_by_name['ADCTrajectory'] = _ADCTRAJECTORY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EStop = _reflection.GeneratedProtocolMessageType('EStop', (_message.Message,), {
  'DESCRIPTOR' : _ESTOP,
  '__module__' : 'modules.planning.proto.planning_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.EStop)
  })
_sym_db.RegisterMessage(EStop)

TaskStats = _reflection.GeneratedProtocolMessageType('TaskStats', (_message.Message,), {
  'DESCRIPTOR' : _TASKSTATS,
  '__module__' : 'modules.planning.proto.planning_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TaskStats)
  })
_sym_db.RegisterMessage(TaskStats)

LatencyStats = _reflection.GeneratedProtocolMessageType('LatencyStats', (_message.Message,), {
  'DESCRIPTOR' : _LATENCYSTATS,
  '__module__' : 'modules.planning.proto.planning_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LatencyStats)
  })
_sym_db.RegisterMessage(LatencyStats)

RSSInfo = _reflection.GeneratedProtocolMessageType('RSSInfo', (_message.Message,), {
  'DESCRIPTOR' : _RSSINFO,
  '__module__' : 'modules.planning.proto.planning_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.RSSInfo)
  })
_sym_db.RegisterMessage(RSSInfo)

ADCTrajectory = _reflection.GeneratedProtocolMessageType('ADCTrajectory', (_message.Message,), {

  'CriticalRegion' : _reflection.GeneratedProtocolMessageType('CriticalRegion', (_message.Message,), {
    'DESCRIPTOR' : _ADCTRAJECTORY_CRITICALREGION,
    '__module__' : 'modules.planning.proto.planning_pb2'
    # @@protoc_insertion_point(class_scope:apollo.planning.ADCTrajectory.CriticalRegion)
    })
  ,
  'DESCRIPTOR' : _ADCTRAJECTORY,
  '__module__' : 'modules.planning.proto.planning_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.ADCTrajectory)
  })
_sym_db.RegisterMessage(ADCTrajectory)
_sym_db.RegisterMessage(ADCTrajectory.CriticalRegion)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_traffic_light.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import direction_pb2 as modules_dot_common_dot_proto_dot_direction__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_traffic_light.proto',
  package='apollo.v2x',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)modules/v2x/proto/v2x_traffic_light.proto\x12\napollo.v2x\x1a!modules/common/proto/header.proto\x1a$modules/common/proto/direction.proto\"\xb2\x03\n\x12SingleTrafficLight\x12\x33\n\x05\x63olor\x18\x01 \x01(\x0e\x32$.apollo.v2x.SingleTrafficLight.Color\x12?\n\x12traffic_light_type\x18\x02 \x03(\x0e\x32#.apollo.v2x.SingleTrafficLight.Type\x12\n\n\x02id\x18\x03 \x01(\t\x12\x1e\n\x16\x63olor_remaining_time_s\x18\x04 \x01(\x05\x12\x18\n\x10right_turn_light\x18\x05 \x01(\x08\x12\x38\n\nnext_color\x18\x06 \x01(\x0e\x32$.apollo.v2x.SingleTrafficLight.Color\x12\x1d\n\x15next_remaining_time_s\x18\x07 \x01(\x01\"P\n\x05\x43olor\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03RED\x10\x01\x12\n\n\x06YELLOW\x10\x02\x12\t\n\x05GREEN\x10\x03\x12\t\n\x05\x42LACK\x10\x04\x12\x0f\n\x0b\x46LASH_GREEN\x10\x05\"5\n\x04Type\x12\x0c\n\x08STRAIGHT\x10\x00\x12\x08\n\x04LEFT\x10\x01\x12\t\n\x05RIGHT\x10\x02\x12\n\n\x06U_TURN\x10\x03\"\xa4\x01\n\x10RoadTrafficLight\x12\x0f\n\x07gps_x_m\x18\x01 \x01(\x01\x12\x0f\n\x07gps_y_m\x18\x02 \x01(\x01\x12<\n\x14single_traffic_light\x18\x03 \x03(\x0b\x32\x1e.apollo.v2x.SingleTrafficLight\x12\x30\n\x0eroad_attribute\x18\x04 \x01(\x0e\x32\x18.apollo.common.Direction\"\xac\x01\n\x1cIntersectionTrafficLightData\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x38\n\x12road_traffic_light\x18\x02 \x03(\x0b\x32\x1c.apollo.v2x.RoadTrafficLight\x12\x17\n\x0fintersection_id\x18\x03 \x01(\x05\x12\x12\n\nconfidence\x18\x04 \x01(\x01'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_direction__pb2.DESCRIPTOR,])



_SINGLETRAFFICLIGHT_COLOR = _descriptor.EnumDescriptor(
  name='Color',
  full_name='apollo.v2x.SingleTrafficLight.Color',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='YELLOW', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GREEN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BLACK', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FLASH_GREEN', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=430,
  serialized_end=510,
)
_sym_db.RegisterEnumDescriptor(_SINGLETRAFFICLIGHT_COLOR)

_SINGLETRAFFICLIGHT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.v2x.SingleTrafficLight.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STRAIGHT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='U_TURN', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=512,
  serialized_end=565,
)
_sym_db.RegisterEnumDescriptor(_SINGLETRAFFICLIGHT_TYPE)


_SINGLETRAFFICLIGHT = _descriptor.Descriptor(
  name='SingleTrafficLight',
  full_name='apollo.v2x.SingleTrafficLight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='color', full_name='apollo.v2x.SingleTrafficLight.color', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='traffic_light_type', full_name='apollo.v2x.SingleTrafficLight.traffic_light_type', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.v2x.SingleTrafficLight.id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='color_remaining_time_s', full_name='apollo.v2x.SingleTrafficLight.color_remaining_time_s', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='right_turn_light', full_name='apollo.v2x.SingleTrafficLight.right_turn_light', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_color', full_name='apollo.v2x.SingleTrafficLight.next_color', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_remaining_time_s', full_name='apollo.v2x.SingleTrafficLight.next_remaining_time_s', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SINGLETRAFFICLIGHT_COLOR,
    _SINGLETRAFFICLIGHT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=131,
  serialized_end=565,
)


_ROADTRAFFICLIGHT = _descriptor.Descriptor(
  name='RoadTrafficLight',
  full_name='apollo.v2x.RoadTrafficLight',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='gps_x_m', full_name='apollo.v2x.RoadTrafficLight.gps_x_m', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gps_y_m', full_name='apollo.v2x.RoadTrafficLight.gps_y_m', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='single_traffic_light', full_name='apollo.v2x.RoadTrafficLight.single_traffic_light', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_attribute', full_name='apollo.v2x.RoadTrafficLight.road_attribute', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=568,
  serialized_end=732,
)


_INTERSECTIONTRAFFICLIGHTDATA = _descriptor.Descriptor(
  name='IntersectionTrafficLightData',
  full_name='apollo.v2x.IntersectionTrafficLightData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.v2x.IntersectionTrafficLightData.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_traffic_light', full_name='apollo.v2x.IntersectionTrafficLightData.road_traffic_light', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intersection_id', full_name='apollo.v2x.IntersectionTrafficLightData.intersection_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='confidence', full_name='apollo.v2x.IntersectionTrafficLightData.confidence', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=735,
  serialized_end=907,
)

_SINGLETRAFFICLIGHT.fields_by_name['color'].enum_type = _SINGLETRAFFICLIGHT_COLOR
_SINGLETRAFFICLIGHT.fields_by_name['traffic_light_type'].enum_type = _SINGLETRAFFICLIGHT_TYPE
_SINGLETRAFFICLIGHT.fields_by_name['next_color'].enum_type = _SINGLETRAFFICLIGHT_COLOR
_SINGLETRAFFICLIGHT_COLOR.containing_type = _SINGLETRAFFICLIGHT
_SINGLETRAFFICLIGHT_TYPE.containing_type = _SINGLETRAFFICLIGHT
_ROADTRAFFICLIGHT.fields_by_name['single_traffic_light'].message_type = _SINGLETRAFFICLIGHT
_ROADTRAFFICLIGHT.fields_by_name['road_attribute'].enum_type = modules_dot_common_dot_proto_dot_direction__pb2._DIRECTION
_INTERSECTIONTRAFFICLIGHTDATA.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_INTERSECTIONTRAFFICLIGHTDATA.fields_by_name['road_traffic_light'].message_type = _ROADTRAFFICLIGHT
DESCRIPTOR.message_types_by_name['SingleTrafficLight'] = _SINGLETRAFFICLIGHT
DESCRIPTOR.message_types_by_name['RoadTrafficLight'] = _ROADTRAFFICLIGHT
DESCRIPTOR.message_types_by_name['IntersectionTrafficLightData'] = _INTERSECTIONTRAFFICLIGHTDATA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SingleTrafficLight = _reflection.GeneratedProtocolMessageType('SingleTrafficLight', (_message.Message,), {
  'DESCRIPTOR' : _SINGLETRAFFICLIGHT,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.SingleTrafficLight)
  })
_sym_db.RegisterMessage(SingleTrafficLight)

RoadTrafficLight = _reflection.GeneratedProtocolMessageType('RoadTrafficLight', (_message.Message,), {
  'DESCRIPTOR' : _ROADTRAFFICLIGHT,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.RoadTrafficLight)
  })
_sym_db.RegisterMessage(RoadTrafficLight)

IntersectionTrafficLightData = _reflection.GeneratedProtocolMessageType('IntersectionTrafficLightData', (_message.Message,), {
  'DESCRIPTOR' : _INTERSECTIONTRAFFICLIGHTDATA,
  '__module__' : 'modules.v2x.proto.v2x_traffic_light_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.IntersectionTrafficLightData)
  })
_sym_db.RegisterMessage(IntersectionTrafficLightData)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/data/proto/static_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.canbus.proto import canbus_conf_pb2 as modules_dot_canbus_dot_proto_dot_canbus__conf__pb2
from modules.canbus.proto import chassis_pb2 as modules_dot_canbus_dot_proto_dot_chassis__pb2
from modules.common.configs.proto import vehicle_config_pb2 as modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2
from modules.control.proto import control_conf_pb2 as modules_dot_control_dot_proto_dot_control__conf__pb2
from modules.routing.proto import routing_pb2 as modules_dot_routing_dot_proto_dot_routing__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/data/proto/static_info.proto',
  package='apollo.data',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/data/proto/static_info.proto\x12\x0b\x61pollo.data\x1a&modules/canbus/proto/canbus_conf.proto\x1a\"modules/canbus/proto/chassis.proto\x1a\x31modules/common/configs/proto/vehicle_config.proto\x1a(modules/control/proto/control_conf.proto\x1a#modules/routing/proto/routing.proto\"\x97\x03\n\x0bVehicleInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x05\x62rand\x18\x02 \x01(\x0e\x32\x1e.apollo.data.VehicleInfo.Brand\x12-\n\x05model\x18\x03 \x01(\x0e\x32\x1e.apollo.data.VehicleInfo.Model\x12+\n\x07license\x18\x04 \x01(\x0b\x32\x16.apollo.canbus.LicenseB\x02\x18\x01\x12.\n\x0b\x63\x61nbus_conf\x18\x05 \x01(\x0b\x32\x19.apollo.canbus.CanbusConf\x12\x34\n\x0evehicle_config\x18\x06 \x01(\x0b\x32\x1c.apollo.common.VehicleConfig\x12\x33\n\x0e\x63ontrol_config\x18\x07 \x01(\x0b\x32\x1b.apollo.control.ControlConf\")\n\x05\x42rand\x12\x0b\n\x07LINCOLN\x10\x01\x12\x08\n\x04\x46ORD\x10\x02\x12\t\n\x05LEXUS\x10\x03\")\n\x05Model\x12\x07\n\x03MKZ\x10\x01\x12\x0b\n\x07TRANSIT\x10\x02\x12\n\n\x06RX450H\x10\x03\"<\n\x0f\x45nvironmentInfo\x12\x14\n\x08map_name\x18\x01 \x01(\tB\x02\x18\x01\x12\x13\n\x0btemperature\x18\x02 \x01(\x02\"w\n\x0cHardwareInfo\x12\x37\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32&.apollo.data.HardwareInfo.ConfigsEntry\x1a.\n\x0c\x43onfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf6\x01\n\x0cSoftwareInfo\x12\x18\n\x0c\x64ocker_image\x18\x01 \x01(\tB\x02\x18\x01\x12\x11\n\tcommit_id\x18\x02 \x01(\t\x12\x10\n\x04mode\x18\x03 \x01(\tB\x02\x18\x01\x12\x37\n\x07\x63onfigs\x18\x04 \x03(\x0b\x32&.apollo.data.SoftwareInfo.ConfigsEntry\x12>\n\x16latest_routing_request\x18\x05 \x01(\x0b\x32\x1e.apollo.routing.RoutingRequest\x1a.\n\x0c\x43onfigsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"=\n\x08UserInfo\x12\x0e\n\x06\x65ntity\x18\x01 \x01(\t\x12\x0e\n\x06\x64river\x18\x02 \x01(\t\x12\x11\n\tco_driver\x18\x03 \x01(\t\"\xe9\x01\n\nStaticInfo\x12)\n\x07vehicle\x18\x01 \x01(\x0b\x32\x18.apollo.data.VehicleInfo\x12\x31\n\x0b\x65nvironment\x18\x02 \x01(\x0b\x32\x1c.apollo.data.EnvironmentInfo\x12+\n\x08hardware\x18\x03 \x01(\x0b\x32\x19.apollo.data.HardwareInfo\x12+\n\x08software\x18\x04 \x01(\x0b\x32\x19.apollo.data.SoftwareInfo\x12#\n\x04user\x18\x05 \x01(\x0b\x32\x15.apollo.data.UserInfo\"D\n\x0eStaticInfoConf\x12\x18\n\x10hardware_configs\x18\x01 \x03(\t\x12\x18\n\x10software_configs\x18\x02 \x03(\t'
  ,
  dependencies=[modules_dot_canbus_dot_proto_dot_canbus__conf__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_chassis__pb2.DESCRIPTOR,modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2.DESCRIPTOR,modules_dot_control_dot_proto_dot_control__conf__pb2.DESCRIPTOR,modules_dot_routing_dot_proto_dot_routing__pb2.DESCRIPTOR,])



_VEHICLEINFO_BRAND = _descriptor.EnumDescriptor(
  name='Brand',
  full_name='apollo.data.VehicleInfo.Brand',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LINCOLN', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FORD', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEXUS', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=583,
  serialized_end=624,
)
_sym_db.RegisterEnumDescriptor(_VEHICLEINFO_BRAND)

_VEHICLEINFO_MODEL = _descriptor.EnumDescriptor(
  name='Model',
  full_name='apollo.data.VehicleInfo.Model',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MKZ', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TRANSIT', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RX450H', index=2, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=626,
  serialized_end=667,
)
_sym_db.RegisterEnumDescriptor(_VEHICLEINFO_MODEL)


_VEHICLEINFO = _descriptor.Descriptor(
  name='VehicleInfo',
  full_name='apollo.data.VehicleInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='apollo.data.VehicleInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='brand', full_name='apollo.data.VehicleInfo.brand', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='model', full_name='apollo.data.VehicleInfo.model', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='license', full_name='apollo.data.VehicleInfo.license', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='canbus_conf', full_name='apollo.data.VehicleInfo.canbus_conf', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='vehicle_config', full_name='apollo.data.VehicleInfo.vehicle_config', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='control_config', full_name='apollo.data.VehicleInfo.control_config', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VEHICLEINFO_BRAND,
    _VEHICLEINFO_MODEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=260,
  serialized_end=667,
)


_ENVIRONMENTINFO = _descriptor.Descriptor(
  name='EnvironmentInfo',
  full_name='apollo.data.EnvironmentInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_name', full_name='apollo.data.EnvironmentInfo.map_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='temperature', full_name='apollo.data.EnvironmentInfo.temperature', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=729,
)


_HARDWAREINFO_CONFIGSENTRY = _descriptor.Descriptor(
  name='ConfigsEntry',
  full_name='apollo.data.HardwareInfo.ConfigsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.data.HardwareInfo.ConfigsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.data.HardwareInfo.ConfigsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=804,
  serialized_end=850,
)

_HARDWAREINFO = _descriptor.Descriptor(
  name='HardwareInfo',
  full_name='apollo.data.HardwareInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='configs', full_name='apollo.data.HardwareInfo.configs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HARDWAREINFO_CONFIGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=731,
  serialized_end=850,
)


_SOFTWAREINFO_CONFIGSENTRY = _descriptor.Descriptor(
  name='ConfigsEntry',
  full_name='apollo.data.SoftwareInfo.ConfigsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='apollo.data.SoftwareInfo.ConfigsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='apollo.data.SoftwareInfo.ConfigsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=804,
  serialized_end=850,
)

_SOFTWAREINFO = _descriptor.Descriptor(
  name='SoftwareInfo',
  full_name='apollo.data.SoftwareInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='docker_image', full_name='apollo.data.SoftwareInfo.docker_image', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit_id', full_name='apollo.data.SoftwareInfo.commit_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode', full_name='apollo.data.SoftwareInfo.mode', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configs', full_name='apollo.data.SoftwareInfo.configs', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='latest_routing_request', full_name='apollo.data.SoftwareInfo.latest_routing_request', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SOFTWAREINFO_CONFIGSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=1099,
)


_USERINFO = _descriptor.Descriptor(
  name='UserInfo',
  full_name='apollo.data.UserInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='entity', full_name='apollo.data.UserInfo.entity', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='driver', full_name='apollo.data.UserInfo.driver', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='co_driver', full_name='apollo.data.UserInfo.co_driver', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1101,
  serialized_end=1162,
)


_STATICINFO = _descriptor.Descriptor(
  name='StaticInfo',
  full_name='apollo.data.StaticInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle', full_name='apollo.data.StaticInfo.vehicle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='environment', full_name='apollo.data.StaticInfo.environment', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hardware', full_name='apollo.data.StaticInfo.hardware', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='software', full_name='apollo.data.StaticInfo.software', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='user', full_name='apollo.data.StaticInfo.user', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1165,
  serialized_end=1398,
)


_STATICINFOCONF = _descriptor.Descriptor(
  name='StaticInfoConf',
  full_name='apollo.data.StaticInfoConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hardware_configs', full_name='apollo.data.StaticInfoConf.hardware_configs', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='software_configs', full_name='apollo.data.StaticInfoConf.software_configs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1400,
  serialized_end=1468,
)

_VEHICLEINFO.fields_by_name['brand'].enum_type = _VEHICLEINFO_BRAND
_VEHICLEINFO.fields_by_name['model'].enum_type = _VEHICLEINFO_MODEL
_VEHICLEINFO.fields_by_name['license'].message_type = modules_dot_canbus_dot_proto_dot_chassis__pb2._LICENSE
_VEHICLEINFO.fields_by_name['canbus_conf'].message_type = modules_dot_canbus_dot_proto_dot_canbus__conf__pb2._CANBUSCONF
_VEHICLEINFO.fields_by_name['vehicle_config'].message_type = modules_dot_common_dot_configs_dot_proto_dot_vehicle__config__pb2._VEHICLECONFIG
_VEHICLEINFO.fields_by_name['control_config'].message_type = modules_dot_control_dot_proto_dot_control__conf__pb2._CONTROLCONF
_VEHICLEINFO_BRAND.containing_type = _VEHICLEINFO
_VEHICLEINFO_MODEL.containing_type = _VEHICLEINFO
_HARDWAREINFO_CONFIGSENTRY.containing_type = _HARDWAREINFO
_HARDWAREINFO.fields_by_name['configs'].message_type = _HARDWAREINFO_CONFIGSENTRY
_SOFTWAREINFO_CONFIGSENTRY.containing_type = _SOFTWAREINFO
_SOFTWAREINFO.fields_by_name['configs'].message_type = _SOFTWAREINFO_CONFIGSENTRY
_SOFTWAREINFO.fields_by_name['latest_routing_request'].message_type = modules_dot_routing_dot_proto_dot_routing__pb2._ROUTINGREQUEST
_STATICINFO.fields_by_name['vehicle'].message_type = _VEHICLEINFO
_STATICINFO.fields_by_name['environment'].message_type = _ENVIRONMENTINFO
_STATICINFO.fields_by_name['hardware'].message_type = _HARDWAREINFO
_STATICINFO.fields_by_name['software'].message_type = _SOFTWAREINFO
_STATICINFO.fields_by_name['user'].message_type = _USERINFO
DESCRIPTOR.message_types_by_name['VehicleInfo'] = _VEHICLEINFO
DESCRIPTOR.message_types_by_name['EnvironmentInfo'] = _ENVIRONMENTINFO
DESCRIPTOR.message_types_by_name['HardwareInfo'] = _HARDWAREINFO
DESCRIPTOR.message_types_by_name['SoftwareInfo'] = _SOFTWAREINFO
DESCRIPTOR.message_types_by_name['UserInfo'] = _USERINFO
DESCRIPTOR.message_types_by_name['StaticInfo'] = _STATICINFO
DESCRIPTOR.message_types_by_name['StaticInfoConf'] = _STATICINFOCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VehicleInfo = _reflection.GeneratedProtocolMessageType('VehicleInfo', (_message.Message,), {
  'DESCRIPTOR' : _VEHICLEINFO,
  '__module__' : 'modules.data.proto.static_info_pb2'
  # @@protoc_insertion_point(class_scope:apollo.data.VehicleInfo)
  })
_sym_db.RegisterMessage(VehicleInfo)

EnvironmentInfo = _reflection.GeneratedProtocolMessageType('EnvironmentInfo', (_message.Message,), {
  'DESCRIPTOR' : _ENVIRONMENTINFO,
  '__module__' : 'modules.data.proto.static_info_pb2'
  # @@protoc_insertion_point(class_scope:apollo.data.EnvironmentInfo)
  })
_sym_db.RegisterMessage(EnvironmentInfo)

HardwareInfo = _reflection.GeneratedProtocolMessageType('HardwareInfo', (_message.Message,), {

  'ConfigsEntry' : _reflection.GeneratedProtocolMessageType('ConfigsEntry', (_message.Message,), {
    'DESCRIPTOR' : _HARDWAREINFO_CONFIGSENTRY,
    '__module__' : 'modules.data.proto.static_info_pb2'
    # @@protoc_insertion_point(class_scope:apollo.data.HardwareInfo.ConfigsEntry)
    })
  ,
  'DESCRIPTOR' : _HARDWAREINFO,
  '__module__' : 'modules.data.proto.static_info_pb2'
  # @@protoc_insertion_point(class_scope:apollo.data.HardwareInfo)
  })
_sym_db.RegisterMessage(HardwareInfo)
_sym_db.RegisterMessage(HardwareInfo.ConfigsEntry)

SoftwareInfo = _reflection.GeneratedProtocolMessageType('SoftwareInfo', (_message.Message,), {

  'ConfigsEntry' : _reflection.GeneratedProtocolMessageType('ConfigsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SOFTWAREINFO_CONFIGSENTRY,
    '__module__' : 'modules.data.proto.static_info_pb2'
    # @@protoc_insertion_point(class_scope:apollo.data.SoftwareInfo.ConfigsEntry)
    })
  ,
  'DESCRIPTOR' : _SOFTWAREINFO,
  '__module__' : 'modules.data.proto.static_info_pb2'
  # @@protoc_insertion_point(class_scope:apollo.data.SoftwareInfo)
  })
_sym_db.RegisterMessage(SoftwareInfo)
_sym_db.RegisterMessage(SoftwareInfo.ConfigsEntry)

UserInfo = _reflection.GeneratedProtocolMessageType('UserInfo', (_message.Message,), {
  'DESCRIPTOR' : _USERINFO,
  '__module__' : 'modules.data.proto.static_info_pb2'
  # @@protoc_insertion_point(class_scope:apollo.data.UserInfo)
  })
_sym_db.RegisterMessage(UserInfo)

StaticInfo = _reflection.GeneratedProtocolMessageType('StaticInfo', (_message.Message,), {
  'DESCRIPTOR' : _STATICINFO,
  '__module__' : 'modules.data.proto.static_info_pb2'
  # @@protoc_insertion_point(class_scope:apollo.data.StaticInfo)
  })
_sym_db.RegisterMessage(StaticInfo)

StaticInfoConf = _reflection.GeneratedProtocolMessageType('StaticInfoConf', (_message.Message,), {
  'DESCRIPTOR' : _STATICINFOCONF,
  '__module__' : 'modules.data.proto.static_info_pb2'
  # @@protoc_insertion_point(class_scope:apollo.data.StaticInfoConf)
  })
_sym_db.RegisterMessage(StaticInfoConf)


_VEHICLEINFO.fields_by_name['license']._options = None
_ENVIRONMENTINFO.fields_by_name['map_name']._options = None
_HARDWAREINFO_CONFIGSENTRY._options = None
_SOFTWAREINFO_CONFIGSENTRY._options = None
_SOFTWAREINFO.fields_by_name['docker_image']._options = None
_SOFTWAREINFO.fields_by_name['mode']._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/perception.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/perception.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_pb=_b('\n\x1c\x63yber/proto/perception.proto\x12\x12\x61pollo.cyber.proto\"\x80\x01\n\nPerception\x12\x35\n\x06header\x18\x01 \x01(\x0b\x32%.apollo.cyber.proto.Perception.Header\x12\x0e\n\x06msg_id\x18\x02 \x01(\x04\x12\x0e\n\x06result\x18\x03 \x01(\x01\x1a\x1b\n\x06Header\x12\x11\n\ttimestamp\x18\x01 \x01(\x04')
)




_PERCEPTION_HEADER = _descriptor.Descriptor(
  name='Header',
  full_name='apollo.cyber.proto.Perception.Header',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.cyber.proto.Perception.Header.timestamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=154,
  serialized_end=181,
)

_PERCEPTION = _descriptor.Descriptor(
  name='Perception',
  full_name='apollo.cyber.proto.Perception',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.cyber.proto.Perception.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='msg_id', full_name='apollo.cyber.proto.Perception.msg_id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='apollo.cyber.proto.Perception.result', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_PERCEPTION_HEADER, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=181,
)

_PERCEPTION_HEADER.containing_type = _PERCEPTION
_PERCEPTION.fields_by_name['header'].message_type = _PERCEPTION_HEADER
DESCRIPTOR.message_types_by_name['Perception'] = _PERCEPTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Perception = _reflection.GeneratedProtocolMessageType('Perception', (_message.Message,), dict(

  Header = _reflection.GeneratedProtocolMessageType('Header', (_message.Message,), dict(
    DESCRIPTOR = _PERCEPTION_HEADER,
    __module__ = 'cyber.proto.perception_pb2'
    # @@protoc_insertion_point(class_scope:apollo.cyber.proto.Perception.Header)
    ))
  ,
  DESCRIPTOR = _PERCEPTION,
  __module__ = 'cyber.proto.perception_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.Perception)
  ))
_sym_db.RegisterMessage(Perception)
_sym_db.RegisterMessage(Perception.Header)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/gnss/proto/imu.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2
from modules.common.proto import geometry_pb2 as modules_dot_common_dot_proto_dot_geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/gnss/proto/imu.proto',
  package='apollo.drivers.gnss',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$modules/drivers/gnss/proto/imu.proto\x12\x13\x61pollo.drivers.gnss\x1a!modules/common/proto/header.proto\x1a#modules/common/proto/geometry.proto\"\xca\x01\n\x03Imu\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x18\n\x10measurement_time\x18\x02 \x01(\x01\x12\x1b\n\x10measurement_span\x18\x03 \x01(\x02:\x01\x30\x12\x33\n\x13linear_acceleration\x18\x04 \x01(\x0b\x32\x16.apollo.common.Point3D\x12\x30\n\x10\x61ngular_velocity\x18\x05 \x01(\x0b\x32\x16.apollo.common.Point3D'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,modules_dot_common_dot_proto_dot_geometry__pb2.DESCRIPTOR,])




_IMU = _descriptor.Descriptor(
  name='Imu',
  full_name='apollo.drivers.gnss.Imu',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.gnss.Imu.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_time', full_name='apollo.drivers.gnss.Imu.measurement_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_span', full_name='apollo.drivers.gnss.Imu.measurement_span', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='linear_acceleration', full_name='apollo.drivers.gnss.Imu.linear_acceleration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='angular_velocity', full_name='apollo.drivers.gnss.Imu.angular_velocity', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=336,
)

_IMU.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
_IMU.fields_by_name['linear_acceleration'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
_IMU.fields_by_name['angular_velocity'].message_type = modules_dot_common_dot_proto_dot_geometry__pb2._POINT3D
DESCRIPTOR.message_types_by_name['Imu'] = _IMU
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Imu = _reflection.GeneratedProtocolMessageType('Imu', (_message.Message,), {
  'DESCRIPTOR' : _IMU,
  '__module__' : 'modules.drivers.gnss.proto.imu_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.Imu)
  })
_sym_db.RegisterMessage(Imu)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/canbus/proto/canbus_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.drivers.canbus.proto import can_card_parameter_pb2 as modules_dot_drivers_dot_canbus_dot_proto_dot_can__card__parameter__pb2
from modules.canbus.proto import vehicle_parameter_pb2 as modules_dot_canbus_dot_proto_dot_vehicle__parameter__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/canbus/proto/canbus_conf.proto',
  package='apollo.canbus',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n&modules/canbus/proto/canbus_conf.proto\x12\rapollo.canbus\x1a\x35modules/drivers/canbus/proto/can_card_parameter.proto\x1a,modules/canbus/proto/vehicle_parameter.proto\"\xf5\x01\n\nCanbusConf\x12:\n\x11vehicle_parameter\x18\x01 \x01(\x0b\x32\x1f.apollo.canbus.VehicleParameter\x12\x43\n\x12\x63\x61n_card_parameter\x18\x02 \x01(\x0b\x32\'.apollo.drivers.canbus.CANCardParameter\x12 \n\x11\x65nable_debug_mode\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\"\n\x13\x65nable_receiver_log\x18\x04 \x01(\x08:\x05\x66\x61lse\x12 \n\x11\x65nable_sender_log\x18\x05 \x01(\x08:\x05\x66\x61lse'
  ,
  dependencies=[modules_dot_drivers_dot_canbus_dot_proto_dot_can__card__parameter__pb2.DESCRIPTOR,modules_dot_canbus_dot_proto_dot_vehicle__parameter__pb2.DESCRIPTOR,])




_CANBUSCONF = _descriptor.Descriptor(
  name='CanbusConf',
  full_name='apollo.canbus.CanbusConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='vehicle_parameter', full_name='apollo.canbus.CanbusConf.vehicle_parameter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_card_parameter', full_name='apollo.canbus.CanbusConf.can_card_parameter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_debug_mode', full_name='apollo.canbus.CanbusConf.enable_debug_mode', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_receiver_log', full_name='apollo.canbus.CanbusConf.enable_receiver_log', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enable_sender_log', full_name='apollo.canbus.CanbusConf.enable_sender_log', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=404,
)

_CANBUSCONF.fields_by_name['vehicle_parameter'].message_type = modules_dot_canbus_dot_proto_dot_vehicle__parameter__pb2._VEHICLEPARAMETER
_CANBUSCONF.fields_by_name['can_card_parameter'].message_type = modules_dot_drivers_dot_canbus_dot_proto_dot_can__card__parameter__pb2._CANCARDPARAMETER
DESCRIPTOR.message_types_by_name['CanbusConf'] = _CANBUSCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CanbusConf = _reflection.GeneratedProtocolMessageType('CanbusConf', (_message.Message,), {
  'DESCRIPTOR' : _CANBUSCONF,
  '__module__' : 'modules.canbus.proto.canbus_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.canbus.CanbusConf)
  })
_sym_db.RegisterMessage(CanbusConf)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/qp_problem.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/qp_problem.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_pb=_b('\n\'modules/planning/proto/qp_problem.proto\x12\x0f\x61pollo.planning\"\xbd\x02\n\x1bQuadraticProgrammingProblem\x12\x12\n\nparam_size\x18\x01 \x01(\x05\x12\x33\n\x10quadratic_matrix\x18\x02 \x01(\x0b\x32\x19.apollo.planning.QPMatrix\x12\x0c\n\x04\x62ias\x18\x03 \x03(\x01\x12\x32\n\x0f\x65quality_matrix\x18\x04 \x01(\x0b\x32\x19.apollo.planning.QPMatrix\x12\x16\n\x0e\x65quality_value\x18\x05 \x03(\x01\x12\x34\n\x11inequality_matrix\x18\x06 \x01(\x0b\x32\x19.apollo.planning.QPMatrix\x12\x18\n\x10inequality_value\x18\x07 \x03(\x01\x12\x14\n\x0cinput_marker\x18\x08 \x03(\x01\x12\x15\n\roptimal_param\x18\t \x03(\x01\"?\n\x08QPMatrix\x12\x10\n\x08row_size\x18\x01 \x01(\x05\x12\x10\n\x08\x63ol_size\x18\x02 \x01(\x05\x12\x0f\n\x07\x65lement\x18\x03 \x03(\x01\"_\n\x1eQuadraticProgrammingProblemSet\x12=\n\x07problem\x18\x01 \x03(\x0b\x32,.apollo.planning.QuadraticProgrammingProblem')
)




_QUADRATICPROGRAMMINGPROBLEM = _descriptor.Descriptor(
  name='QuadraticProgrammingProblem',
  full_name='apollo.planning.QuadraticProgrammingProblem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='param_size', full_name='apollo.planning.QuadraticProgrammingProblem.param_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quadratic_matrix', full_name='apollo.planning.QuadraticProgrammingProblem.quadratic_matrix', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bias', full_name='apollo.planning.QuadraticProgrammingProblem.bias', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='equality_matrix', full_name='apollo.planning.QuadraticProgrammingProblem.equality_matrix', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='equality_value', full_name='apollo.planning.QuadraticProgrammingProblem.equality_value', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inequality_matrix', full_name='apollo.planning.QuadraticProgrammingProblem.inequality_matrix', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inequality_value', full_name='apollo.planning.QuadraticProgrammingProblem.inequality_value', index=6,
      number=7, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='input_marker', full_name='apollo.planning.QuadraticProgrammingProblem.input_marker', index=7,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='optimal_param', full_name='apollo.planning.QuadraticProgrammingProblem.optimal_param', index=8,
      number=9, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=61,
  serialized_end=378,
)


_QPMATRIX = _descriptor.Descriptor(
  name='QPMatrix',
  full_name='apollo.planning.QPMatrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='row_size', full_name='apollo.planning.QPMatrix.row_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='col_size', full_name='apollo.planning.QPMatrix.col_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='element', full_name='apollo.planning.QPMatrix.element', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=443,
)


_QUADRATICPROGRAMMINGPROBLEMSET = _descriptor.Descriptor(
  name='QuadraticProgrammingProblemSet',
  full_name='apollo.planning.QuadraticProgrammingProblemSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='problem', full_name='apollo.planning.QuadraticProgrammingProblemSet.problem', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=445,
  serialized_end=540,
)

_QUADRATICPROGRAMMINGPROBLEM.fields_by_name['quadratic_matrix'].message_type = _QPMATRIX
_QUADRATICPROGRAMMINGPROBLEM.fields_by_name['equality_matrix'].message_type = _QPMATRIX
_QUADRATICPROGRAMMINGPROBLEM.fields_by_name['inequality_matrix'].message_type = _QPMATRIX
_QUADRATICPROGRAMMINGPROBLEMSET.fields_by_name['problem'].message_type = _QUADRATICPROGRAMMINGPROBLEM
DESCRIPTOR.message_types_by_name['QuadraticProgrammingProblem'] = _QUADRATICPROGRAMMINGPROBLEM
DESCRIPTOR.message_types_by_name['QPMatrix'] = _QPMATRIX
DESCRIPTOR.message_types_by_name['QuadraticProgrammingProblemSet'] = _QUADRATICPROGRAMMINGPROBLEMSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QuadraticProgrammingProblem = _reflection.GeneratedProtocolMessageType('QuadraticProgrammingProblem', (_message.Message,), dict(
  DESCRIPTOR = _QUADRATICPROGRAMMINGPROBLEM,
  __module__ = 'modules.planning.proto.qp_problem_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.QuadraticProgrammingProblem)
  ))
_sym_db.RegisterMessage(QuadraticProgrammingProblem)

QPMatrix = _reflection.GeneratedProtocolMessageType('QPMatrix', (_message.Message,), dict(
  DESCRIPTOR = _QPMATRIX,
  __module__ = 'modules.planning.proto.qp_problem_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.QPMatrix)
  ))
_sym_db.RegisterMessage(QPMatrix)

QuadraticProgrammingProblemSet = _reflection.GeneratedProtocolMessageType('QuadraticProgrammingProblemSet', (_message.Message,), dict(
  DESCRIPTOR = _QUADRATICPROGRAMMINGPROBLEMSET,
  __module__ = 'modules.planning.proto.qp_problem_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.QuadraticProgrammingProblemSet)
  ))
_sym_db.RegisterMessage(QuadraticProgrammingProblemSet)


# @@protoc_insertion_point(module_scope)
